@@ -1,3 +1,5 @@
+import unittest
+
 from tests.basic_test import BasicTestCase, db
 from tests.crud import *
 from sqlbatis.sqlbatis_dao import SQLBatisDao
@@ -15,6 +17,8 @@ class BasicDaoWhereTestCase(BasicTestCase):
         user_dao = UserDao()
         user_dao.bulk_insert(users)
         results = user_dao.filter_by({'name': 'leo2'}).all()
+        self.assertEqual(len(results), 1)
+        self.assertEqual(results[0].name, 'leo2')
 
         assert len(results) == 1
         assert results[0].name == 'leo2'
@@ -23,20 +27,20 @@ class BasicDaoWhereTestCase(BasicTestCase):
         user_dao = UserDao()
         user_dao.bulk_insert(users)
         results = user_dao.filter_by({'name': 'leo2', 'id': 2}).all()
-        assert len(results) == 0
+        self.assertEqual(len(results), 0)
         results = user_dao.filter_by({'name': 'leo2', 'id': 3}).all()
-        assert len(results) == 1
+        self.assertEqual(len(results), 1)
 
     def test_3_empty_where(self):
         user_dao = UserDao()
         user_dao.bulk_insert(users)
         results = user_dao.filter_by({}).all()
-        assert len(results) == 6
+        self.assertEqual(len(results), 6)
 
     def test_4_where_multiple_records(self):
         user_dao = UserDao()
         results = user_dao.filter_by({'name': 'leo2'}).all()
-        assert len(results) == 3
+        self.assertEqual(len(results), 3)
 
 
 if __name__ == '__main__':
