@@ -1,3 +1,5 @@
+import unittest
+
 from tests.basic_test import BasicTestCase, db
 from tests.crud import *
 
@@ -10,14 +12,13 @@ class RowTestCase(BasicTestCase):
 
     def test_row_2_get(self):
         result = select().first()
-        assert result.name == 'leo1'
-        assert result.get('name') == 'leo1'
+        self.assertEqual(result.name, 'leo1')
+        self.assertEqual(result.get('name'), 'leo1')
 
     def test_row_3_to_dict(self):
         result = select().first().to_dict()
-
-        assert isinstance(result, dict) == True
-        assert result['name'] == 'leo1'
+        self.assertEqual(isinstance(result, dict), True)
+        self.assertEqual(result['name'], 'leo1')
 
 
 if __name__ == '__main__':
